Module admin_http

Module admin_http 

Structs

AdminDiagnosticResetReply
Verified owner counts returned by the local diagnostic reset.
AdminDrainReply
Admin drain response.
AdminErrorReply
JSON reply for rejected admin calls.
AdminHttpSurface
Axum route owner for the internal admin/operator surface.

Enums

AdminHttpError
Admin HTTP boundary errors.

Constants

ADMIN_ACTUATOR_PATH
Read-only per-cache actuator path on the internal admin surface.
ADMIN_BACKUP_PATH
Operator backup action path.
ADMIN_CLUSTER_OVERVIEW_PATH
Read-only cluster overview path on the internal admin surface.
ADMIN_CONSOLE_PATH
Read-only Management Center console path on the internal admin surface.
ADMIN_DIAGNOSTIC_RESET_PATH
Off-by-default, local-only destructive diagnostic reset path.
ADMIN_DRAIN_PATH
Operator drain action path.
ADMIN_HEALTHZ_PATH
Liveness path used by Kubernetes probes.
ADMIN_METRICS_PATH
Prometheus metrics path on the internal admin surface.
ADMIN_RAFT_COMPACTION_PATH
Explicit, off-by-default disk-backed Raft compaction control and status path.
ADMIN_READYZ_PATH
Readiness path used by Kubernetes probes.
ADMIN_RESHARD_PATH
Operator reshard action path.
ADMIN_STATUS_PATH
Operator status path.

Type Aliases

SharedServerRuntime
Shared runtime state for the admin HTTP surface.