pub struct AdminHttpSurface { /* private fields */ }Expand description
Axum route owner for the internal admin/operator surface.
Implementations
Sourceimpl AdminHttpSurface
impl AdminHttpSurface
Sourcepub fn new(runtime: ServerRuntime) -> Self
pub fn new(runtime: ServerRuntime) -> Self
Create an admin surface from a server runtime.
Create an admin surface from shared runtime state.
Sourcepub fn with_hc2_metrics(self, service: Hc2ClientPlaneService) -> Self
pub fn with_hc2_metrics(self, service: Hc2ClientPlaneService) -> Self
Attach the selected production HC/2 listener to the internal metrics surface. This does not expose metrics on either public client port.
Sourcepub fn runtime(&self) -> SharedServerRuntime
pub fn runtime(&self) -> SharedServerRuntime
Return shared runtime state for tests and embedding code.