pub struct ServerAdminStatus {
pub source: StatusSource,
pub leader: Option<String>,
pub term: u64,
pub epoch: u64,
pub quorum_ok: bool,
pub members: u32,
pub member_ids: Vec<String>,
pub voters: u32,
pub voter_ids: Vec<u64>,
pub reshard_phase: String,
pub draining: bool,
}Expand description
Admin status consumed by the Kubernetes operator.
Fields
source: StatusSourceWhether this status is live or modeled.
leader: Option<String>Current leader id if known to the runtime.
term: u64Current control-plane term if known.
epoch: u64Current committed membership authority epoch.
quorum_ok: boolWhether the runtime believes quorum is available.
members: u32Observed member count.
member_ids: Vec<String>Sorted logical member ids in the committed metadata view.
voters: u32Observed raft voter count.
voter_ids: Vec<u64>Sorted numeric ids in the committed Raft voter set.
reshard_phase: StringCurrent reshard phase.
draining: boolWhether the runtime is draining.