pub struct RaftCompactionStatus {Show 13 fields
pub available: bool,
pub enabled: bool,
pub applied_index: Option<u64>,
pub snapshot_index: Option<u64>,
pub first_log_index: Option<u64>,
pub last_log_index: Option<u64>,
pub snapshot_send_attempts: Option<u64>,
pub snapshot_send_successes: Option<u64>,
pub snapshot_send_failures: Option<u64>,
pub snapshot_sends_in_flight: Option<u64>,
pub snapshot_sender_tasks_current: Option<u64>,
pub snapshot_sender_tasks_high_water: Option<u64>,
pub snapshot_installs: Option<u64>,
}Expand description
Read-only state of the disk-backed Raft compaction control.
Fields
available: boolWhether the current runtime owns a disk-backed Raft log.
enabled: boolWhether explicit compaction requests are enabled by configuration.
applied_index: Option<u64>Last locally applied Raft index, when available.
snapshot_index: Option<u64>Durable snapshot index, when available.
first_log_index: Option<u64>First retained durable log index, when available.
last_log_index: Option<u64>Last durable log index, when available.
snapshot_send_attempts: Option<u64>Real HTTP snapshot send attempts since this daemon started.
snapshot_send_successes: Option<u64>Successful real HTTP snapshot sends since this daemon started.
snapshot_send_failures: Option<u64>Failed or timed-out real HTTP snapshot sends since this daemon started.
snapshot_sends_in_flight: Option<u64>Real HTTP snapshot requests currently awaiting an outcome.
snapshot_sender_tasks_current: Option<u64>Actual per-peer sender tasks currently carrying a valid Raft snapshot.
snapshot_sender_tasks_high_water: Option<u64>Per-daemon high-water mark of concurrent snapshot sender tasks since this process started; it resets when the daemon restarts.
snapshot_installs: Option<u64>Snapshots installed into the local Raft state machine this process run.