ServerConfigError

Enum ServerConfigError 

pub enum ServerConfigError {
Show 37 variants ConfigRead { path: PathBuf, source: Error, }, ConfigParse(Error), InvalidRole(String), InvalidClusterStart(String), InvalidAddress(String), InvalidBootstrapReplicas(String), InvalidStatefulSetHostname(String), InvalidJoinTimeoutMs(String), DrainTimeoutZero, JoinTimeoutZero, JoinRequiresMemberRole, JoinRequiresSeeds, MissingStorageDir, RaftCompactionRequiresMember, MissingSeeds, InvalidNodeId, InvalidClusterAdvertiseAddr, MissingBackupLocation, IncompleteTlsMaterial, IncompleteClusterAuth { section: &'static str, }, ClusterAuthTokenRead { section: &'static str, path: PathBuf, source: Error, }, EmptyClusterAuthToken { section: &'static str, path: PathBuf, }, NonLoopbackWithoutTls, InvalidClientApi(String), GridHostStart(String), AdminAddressConflicts, UnsafeDiagnosticReset, RedisAddressConflicts { surface: &'static str, }, IncompleteRedisAuth, RedisAuthTokenRead { path: PathBuf, source: Error, }, EmptyRedisAuthToken { path: PathBuf, }, RedisRedissRequiresTls, InvalidRedisEventSubscriptionLimit, InvalidRedisEventSubscriptionByteLimit, Hc2RequiresMutualTls, InvalidHc2ClusterId, Hc2AddressConflicts { surface: &'static str, },
}
Fail-loud configuration errors.

Variants



ConfigRead

Config file could not be read.

Fields

path: PathBuf

Config path.

source: Error

Source IO error.



ConfigParse(Error)

Config file could not be parsed.



InvalidRole(String)

Role value is unknown.



InvalidClusterStart(String)

Cluster start mode value is unknown.



InvalidAddress(String)

Address value is invalid.



InvalidBootstrapReplicas(String)

StatefulSet bootstrap replica count could not be parsed.



InvalidStatefulSetHostname(String)

StatefulSet hostname could not be used to derive an ordinal identity.



InvalidJoinTimeoutMs(String)

Join timeout value could not be parsed.



DrainTimeoutZero

Drain timeout cannot be zero.



JoinTimeoutZero

Join timeout cannot be zero.



JoinRequiresMemberRole

Join mode is only valid for durable members.



JoinRequiresSeeds

Join mode requires at least one seed.



MissingStorageDir

Member mode requires durable state.



RaftCompactionRequiresMember

The disk-backed compaction seam is only valid for durable members.



MissingSeeds

Member/client mode requires seeds.



InvalidNodeId

Configured node identity cannot be empty.



InvalidClusterAdvertiseAddr

Advertised cluster endpoint must be a routable non-empty endpoint.



MissingBackupLocation

Backup enabled without a destination.



IncompleteTlsMaterial

TLS enabled without full material paths.



IncompleteClusterAuth

Cluster auth material is incomplete.

Fields

section: &'static str

Config section.



ClusterAuthTokenRead

Cluster auth token file could not be read.

Fields

section: &'static str

Config section.

path: PathBuf

Token file path.

source: Error

Source IO error.



EmptyClusterAuthToken

Cluster auth token file was empty.

Fields

section: &'static str

Config section.

path: PathBuf

Token file path.



NonLoopbackWithoutTls

External listener without TLS and without explicit acknowledgement.



InvalidClientApi(String)

External client API config is invalid.



GridHostStart(String)

Member grid host could not be constructed.



AdminAddressConflicts

Admin and client/listen surfaces must be independently bindable.



UnsafeDiagnosticReset

Destructive diagnostic reset is restricted to an enabled loopback admin surface in local mode.



RedisAddressConflicts

Redis RESP and existing surfaces must be independently bindable.

Fields

surface: &'static str

Conflicting surface.



IncompleteRedisAuth

Redis AUTH required without readable token material.



RedisAuthTokenRead

Redis AUTH token file could not be read.

Fields

path: PathBuf

Token file path.

source: Error

Source IO error.



EmptyRedisAuthToken

Redis AUTH token file was empty.

Fields

path: PathBuf

Token file path.



RedisRedissRequiresTls

Native rediss:// requires server TLS material.



InvalidRedisEventSubscriptionLimit

Redis event listeners require a non-zero per-connection subscription bound.



InvalidRedisEventSubscriptionByteLimit

Redis event listeners require a non-zero retained subscription-byte bound.



Hc2RequiresMutualTls

HC/2 never exposes a plaintext production constructor/listener.



InvalidHc2ClusterId

Cluster identity must be non-empty when HC/2 is enabled.



Hc2AddressConflicts

HC/2 must own an independently bindable port.

Fields

surface: &'static str

Conflicting surface.