pub struct Hc2ClientPlaneService { /* private fields */ }Expand description
Production gRPC service. Construction requires existing verified dispatch state.
Implementations
Sourceimpl Hc2ClientPlaneService
impl Hc2ClientPlaneService
Sourcepub fn new(
state: Arc<ClientSurfaceState>,
cluster_id: impl Into<String>,
) -> Self
pub fn new( state: Arc<ClientSurfaceState>, cluster_id: impl Into<String>, ) -> Self
Construct a service over the shared HC/1/RESP dispatch state.
Sourcepub fn accounting(&self) -> Hc2AccountingSnapshot
pub fn accounting(&self) -> Hc2AccountingSnapshot
Return bounded, secret-free listener accounting.
Sourcepub fn prometheus_metrics(&self) -> String
pub fn prometheus_metrics(&self) -> String
Render the production listener’s bounded aggregate accounting for the existing internal Prometheus endpoint.
The only label has a closed domain. Peer identities, tenant IDs, authorities, certificate material, keys, and values are never exposed.