Standalone HydraCache server bootstrap primitives.
The crate keeps the first production daemon surface framework-neutral where possible: configuration, validation, readiness, and graceful drain can be tested without binding sockets. The binary wrapper wires these primitives to process startup.
Re-exports
pub use admin_http::AdminDiagnosticResetReply;pub use admin_http::AdminHttpError;pub use admin_http::AdminHttpSurface;pub use admin_http::ADMIN_ACTUATOR_PATH;pub use admin_http::ADMIN_BACKUP_PATH;pub use admin_http::ADMIN_CLUSTER_OVERVIEW_PATH;pub use admin_http::ADMIN_CONSOLE_PATH;pub use admin_http::ADMIN_DIAGNOSTIC_RESET_PATH;pub use admin_http::ADMIN_DRAIN_PATH;pub use admin_http::ADMIN_HEALTHZ_PATH;pub use admin_http::ADMIN_METRICS_PATH;pub use admin_http::ADMIN_RAFT_COMPACTION_PATH;pub use admin_http::ADMIN_READYZ_PATH;pub use admin_http::ADMIN_RESHARD_PATH;pub use admin_http::ADMIN_STATUS_PATH;pub use bootstrap::RedisSurfaceDrain;pub use bootstrap::ServerAdminAction;pub use bootstrap::ServerAdminActionError;pub use bootstrap::ServerAdminStatus;pub use bootstrap::ServerHealth;pub use bootstrap::ServerObservabilityModel;pub use bootstrap::ServerReadiness;pub use bootstrap::ServerRuntime;pub use bootstrap::ServerState;pub use cluster_status::ClusterStatus;pub use cluster_status::ClusterStatusProvider;pub use cluster_status::ClusterStatusRuntime;pub use cluster_status::GridControlPlaneHandle;pub use cluster_status::LiveClusterStatus;pub use cluster_status::MemberRole;pub use cluster_status::MemberStatus;pub use cluster_status::ModeledClusterStatus;pub use cluster_status::RaftCompactionError;pub use cluster_status::RaftCompactionStatus;pub use cluster_status::Reachability;pub use cluster_status::ReshardPhase;pub use cluster_status::StatusSource;pub use config::AdminApiConfig;pub use config::BackupConfig;pub use config::ClientApiConfig;pub use config::ClusterAuthConfig;pub use config::ClusterStartMode;pub use config::Hc2ClientPlaneConfig;pub use config::RedisApiConfig;pub use config::ServerConfig;pub use config::ServerConfigError;pub use config::ServerRole;pub use config::TlsConfig;pub use hc2::serve_hc2_listener;pub use hc2::Hc2ClientPlaneService;pub use hc2::Hc2ListenerTls;pub use hc2::Hc2ServeError;pub use redis_tcp::serve_redis_listener;pub use redis_tcp::RedisTcpError;pub use redis_tcp::RedisTlsAcceptor;pub use redis_tcp::RedisTlsError;pub use services::DrainOutcome;pub use services::GracefulShutdown;pub use services::ServiceSet;pub use upgrade::GracefulUpgrade;pub use upgrade::UpgradeError;pub use upgrade::UpgradePhase;pub use upgrade::UpgradePlan;pub use upgrade::UpgradeReport;pub use upgrade::UpgradeStrategy;
Modules
- admin_
http - bootstrap
- cluster_
status - Honest cluster-status seam for the admin and Management Center surfaces.
- config
- hc2
- Production HC/2 listener backed by the existing verified client dispatch.
- redis_
tcp - services
- upgrade